Course class

Constructors

Course({required int id, required String title, required String url, String? shortDescription, String? longDescription, int? pastLearners, int? activeLearners, Category? category, FeaturedMedia? featuredMedia, Cta? cta, List<String>? learningOutcomes, ResourcesSummary? resourcesSummary, Academy? academy, List<Personalization>? personalization, CourseAvailability? availability, CourseDuration? duration, TeachingMode? teachingMode, CourseSchedule? schedule, List<CourseEconomics>? economics, List<Instructor>? instructors, String? cancellationPolicy})
Course.fromJson(Map<String, dynamic> json)
factory

Properties

academy Academy?
getter/setter pair
activeLearners int?
getter/setter pair
availability CourseAvailability?
getter/setter pair
cancellationPolicy String?
getter/setter pair
category Category?
getter/setter pair
cta Cta?
getter/setter pair
duration CourseDuration?
getter/setter pair
economics List<CourseEconomics>?
getter/setter pair
featuredMedia FeaturedMedia?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
instructors List<Instructor>?
getter/setter pair
learningOutcomes List<String>?
getter/setter pair
longDescription String?
getter/setter pair
pastLearners int?
getter/setter pair
personalization List<Personalization>?
getter/setter pair
resourcesSummary ResourcesSummary?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule CourseSchedule?
getter/setter pair
shortDescription String?
getter/setter pair
teachingMode TeachingMode?
getter/setter pair
title String
getter/setter pair
url String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited